@@ -14,22 +14,23 @@
 # Free Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 # MA  02111-1307  USA
 
-# Copyrights (C) for this R-port:
-#   1999 - 2012 Diethelm Wuertz, Zurich, <wuertz@itp.phys.ethz.ch>
-#   2009 - 2012 Rmetrics Association, Zurich, www.rmetrics.org
-
 
 ################################################################################
 # FUNCTION:               DESCRIPTION:
 #  read.lines              A synonyme function call to readLines
 ################################################################################
 
+
 # wrapper function of read.lines to have consistent function names as
 # described in ebook.
 
-read.lines <- function(con = stdin(), n = -1L, ok = TRUE, warn = FALSE,
-                       encoding = "unknown")
+
+read.lines <- 
+    function(con = stdin(), n = -1L, ok = TRUE, warn = FALSE,
+    encoding = "unknown")
+{
     readLines(con = con, n = n, ok = ok, warn = warn, encoding = encoding)
+}
 
 ################################################################################
 
